/* -*- Mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; tab-width: 40 -*- */
/* vim: set ts=2 et sw=2 tw=40: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

interface nsIDOMCameraManager;

[scriptable,
uuid(46a5710b-8dfb-430e-8705-90bea31c55aa)]
interface nsIDOMNavigatorCamera : nsISupports
{
  readonly attribute nsISupports mozCameras;
};
