/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef mozilla_dom_network_Utils_h
#define mozilla_dom_network_Utils_h

namespace mozilla {
namespace dom {
namespace network {

/**
 * Returns whether the Network API is enabled.
 * @return whether the Network API is enabled.
 */
extern bool IsAPIEnabled();

} // namespace network
} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_network_Utils_h

